@@ -46,9 +46,20 @@ print "and some proc info \\P{\%u up \%w users, loadavg: \%L}\n\t= $PS1\n";
 
 print "\nAnd now for some real prompts:\n\n";
 
-print Env::PS1->sprintf($_), "\n\n"
-	for '\C{bold,blue}\u@\H \A \C{green}\W\$\C{reset} ',
+print Env::PS1->sprintf($_), "\n\n" for
+	'\C{bold,blue}\u@\H \A \C{green}\W\$\C{reset} ',
 	'\[\033[01;31m\]\h \[\033[01;34m\]\W \$ \[\033[00m\]',
 	'\C{green}\D{%H:%M:%S} \W\$\C{reset} ',
 	'\C{bold,black}/--( \u@\H )-( \t )-( \w )- * *\n\\-- * \$\C{reset} ';
 	
+__END__
+
+=head1 NAME
+
+example.pl - some prompts demonstrated
+
+=head1 DESCRIPTION
+
+This script demonstrates the module by
+showing the supported escape sequences and some prompts.
+
